@@ -3,14 +3,18 @@ from databases import Database
 from pywolf.db.config import Validator
 from pywolf.db.executor import Executor
 
+
 class Db(object):
+    def __init__(self):
+        self.conn_dict = None
+        self.config = None
+
     def init_config(self, config: dict):
         if not Validator().validate(dict):
             raise SyntaxError("invalid database config")
 
         self.config = config
         self.conn_dict = {}
-        
 
     async def connect(self, dbname: str = 'default'):
         if dbname in self.conn_dict:
@@ -23,9 +27,9 @@ class Db(object):
         conn = Database(self.config.get(dbname).get('url'))
         await conn.connect()
         self.conn_dict[dbname] = conn
-        
-        return Executor(conn)     
-    
+
+        return Executor(conn)
+
     async def disconnect(self):
         pass
 
@@ -35,4 +39,3 @@ class Db(object):
 
 
 db = Db()
-
